@@ -15,6 +15,7 @@ mod dfs;
 mod dijkstra;
 mod edmonds_karp;
 mod fringe;
+mod grid;
 mod idastar;
 mod kuhn_munkres;
 mod matrix;
@@ -27,6 +28,7 @@ pub use dfs::*;
 pub use dijkstra::*;
 pub use edmonds_karp::*;
 pub use fringe::*;
+pub use grid::*;
 pub use idastar::*;
 pub use kuhn_munkres::*;
 pub use matrix::*;
